==> service_layer_rest-0.1.5.gem: app/models/service_layer_rest/user.rb <==
module ServiceLayerRest
  class User
    include ActiveModel::Validations    # required because some before_validations are defined in devise
    extend ActiveModel::Callbacks       # required to define callbacks
    extend Devise::Models

    define_model_callbacks :validation  # required by Devise

    devise :delphi_authenticatable

    attr_accessor :id, :iD_BVBenutzer, :iD_MicosBenutzer, :zeitErf_ID, :personalNr, :bVBenutzer_Login,
                  :micosBenutzer_Login, :system_Login, :benutzer_Passwort, :system_Passwort, :authtype,
                  :aktiv, :groupID, :oldUserID, :pepMitarbeiterID, :micosMitarbeiterID, :institutionID,
                  :mandantId, :useNewBV, :isAdmin, :isMicos, :mitarbeiterName, :employees

    def initialize(attributes = {})
      mass_assign(attributes)
    end

    def mass_assign(attributes)
      attributes.each do |attribute, value|
        respond_to?(:"#{attribute}=") && send(:"#{attribute}=", value)
      end
    end

    def print
      {
        :id => self.id,

        :iD_BVBenutzer => self.iD_BVBenutzer,
        :iD_MicosBenutzer => self.iD_MicosBenutzer,
        :zeitErf_ID => self.zeitErf_ID,
        :personalNr => self.personalNr,
        :bVBenutzer_Login => self.bVBenutzer_Login,
        :micosBenutzer_Login => self.micosBenutzer_Login,
        :system_Login => self.system_Login,
        :benutzer_Passwort => self.benutzer_Passwort,
        :system_Passwort => self.system_Passwort,
        :authtype => self.authtype,

        :aktiv => self.aktiv,
        :groupID => self.groupID,
        :oldUserID => self.oldUserID,
        :pepMitarbeiterID => self.pepMitarbeiterID,
        :micosMitarbeiterID => self.micosMitarbeiterID,
        :institutionID => self.institutionID,
        :mandantId => self.mandantId,
        :useNewBV => self.useNewBV,
        :isAdmin => self.isAdmin,

        :isMicos => self.isMicos,

        :mitarbeiterName => self.mitarbeiterName,
      }
    end

    def as_json
      self.print.to_json
    end
  end
end

==> service_layer_rest-0.1.34.gem: app/models/service_layer_rest/user.rb <==
module ServiceLayerRest
  class User
    include ActiveModel::Validations    # required because some before_validations are defined in devise
    extend ActiveModel::Callbacks       # required to define callbacks
    extend Devise::Models

    define_model_callbacks :validation  # required by Devise

    devise :delphi_authenticatable

    attr_accessor :id, :iD_BVBenutzer, :iD_MicosBenutzer, :zeitErf_ID, :personalNr, :bVBenutzer_Login,
                  :micosBenutzer_Login, :system_Login, :benutzer_Passwort, :system_Passwort, :authtype,
                  :vertretungsmodus, :aktiv, :groupID, :oldUserID, :pepMitarbeiterID, :micosMitarbeiterID, 
                  :institutionID, :mandantId, :useNewBV, :isAdmin, :isMicos, :mitarbeiterName, :employees

    def initialize(attributes = {})
      mass_assign(attributes)
    end

    def mass_assign(attributes)
      attributes.each do |attribute, value|
        respond_to?(:"#{attribute}=") && send(:"#{attribute}=", value)
      end
    end

    def print
      {
        :id => self.id,

        :iD_BVBenutzer => self.iD_BVBenutzer,
        :iD_MicosBenutzer => self.iD_MicosBenutzer,
        :zeitErf_ID => self.zeitErf_ID,
        :personalNr => self.personalNr,
        :bVBenutzer_Login => self.bVBenutzer_Login,
        :micosBenutzer_Login => self.micosBenutzer_Login,
        :system_Login => self.system_Login,
        :benutzer_Passwort => self.benutzer_Passwort,
        :system_Passwort => self.system_Passwort,
        :authtype => self.authtype,
        :vertretungsmodus => self.vertretungsmodus,

        :aktiv => self.aktiv,
        :groupID => self.groupID,
        :oldUserID => self.oldUserID,
        :pepMitarbeiterID => self.pepMitarbeiterID,
        :micosMitarbeiterID => self.micosMitarbeiterID,
        :institutionID => self.institutionID,
        :mandantId => self.mandantId,
        :useNewBV => self.useNewBV,
        :isAdmin => self.isAdmin,

        :isMicos => self.isMicos,

        :mitarbeiterName => self.mitarbeiterName,
      }
    end

    def as_json
      self.print.to_json
    end
  end
end
